######################################
# Statistical methods for data science: R 
#
# http://didawiki.di.unipi.it/doku.php/mds/smd/ 
######################################

# [CTRL-Enter] to execute a line

###### Script R7: Moments ##########

# positive skewness and platykurtic
x = rbinom(1000, 50, 0.1)
plot(table(x))
mu = mean(x)
sigma = sqrt(mean((x-mu)^2)) # approx sd(x)
mu3 = mean((x-mu)^3)/sigma^3
mu3
# or using library
library(moments)
skewness(x)
kurtosis(x)


# SET WORKING DIR FOR I/O
wdir = "C:/Users/Salvatore Ruggieri/Desktop/tmp"
setwd(wdir)
# Data from Human Mortality Database https://www.mortality.org (require registration)
# library(HMDHFDplus)
# mortalitycount = readHMDweb(CNTRY='ITA', item='Deaths_1x1', username='<username>', password='<pwd>')
# save(mortalitycount, file="mortalitycount.Rdata")
load(file="2019smdR7.Rdata")
View(mortalitycount)

# negative skewness and leptokurtic
year = 2015
ndeaths = mortalitycount[mortalitycount$Year==year,]$Total
ages = mortalitycount[mortalitycount$Year==year,]$Age
plot(ages, ndeaths)
x = rep(ages, ndeaths)
mean(x)
plot(table(x)/length(x), xlab="ages", ylab="pmf")
skewness(x)
kurtosis(x)


###### Script R7: Computation with random variables ##########

# the area Y = pi*R^2 for a uniform R is NOT uniform!

# pdf of Y = g(R) = pi*R^2 for R ~ U(0, 1)
curve( 1/sqrt(4 * pi * x), xlim=c(0, pi), ylim=c(0, 2)) 
# cdf of Y = g(R) = pi*R^2 for R ~ U(0, 1)
curve( sqrt(x/pi), add=TRUE, col=2) # cdf


###### Script R7: Joint distributions ##########

# discrete random variable example
outer(1:6, 1:6, "+")
sumv = as.vector(outer(1:6, 1:6, "+"))
sumv
outer(1:6, 1:6, pmax)
maxv = as.vector(outer(1:6, 1:6, pmax))
maxv
joint.pmf = table(sumv, maxv)
joint.pmf

library(plot3D)
hist3D(z=joint.pmf/36, ticktype="detailed", space=0.1, shade=0.5)
image2D(joint.pmf/36)

# sum as marginal distribution
sum.marginal.pmf = apply(joint.pmf, 1, sum)
sum.marginal.pmf
table(sumv)
# max as marginal distribution
max.marginal.pmf = apply(joint.pmf, 2, sum)
max.marginal.pmf
table(maxv)

joint.cdf = t(apply(apply(joint.pmf, 2, cumsum), 1, cumsum))
joint.cdf
image2D(joint.cdf/36)

# bivariate normal density
f = function(x, y) { 30/pi * exp(-50*x^2 - 50*y^2+80*x*y) }
# grid to plot 
x = seq(-0.4, 0.4, length= 100)
y = x
# sample values over the grid
z = outer(x, y, f)
# perspective Plot
persp(x,y,z, theta = -45, phi = 45, expand = 0.5, col = "lightblue", ticktype="detailed")

